@@ -51,6 +51,9 @@ REMOVE_EDGE_FRAMES = True
 LIFETIME_MIN_FOR_PLOT = 1
 # Minimum lifetime to mark a dot in the output figure. The default value is 1, so that all dots with a lifetime of 1 or greater are plotted.
 
+LIFETIME_THRESHOLD = 0
+# Used to mark shorter lifetimes as unreliable from noisy datasets (with a "y" in the last column of the output file). The value given will be the upper limit of the lifetimes marked as reliable (e.g., a value of 3 will mark lifetimes of 1, 2, and 3). Increase to include less noise (and remove shorter lifetimes), and decrease for the opposite. The default value is 0, which is the minimum value that includes all lifetimes.
+
 ######################################
 ############ DOT SETTINGS ############
 ######################################
@@ -100,8 +103,8 @@ POLYGON_THICKNESS = 0.5
 DYNAMIC_WINDOW = True
 # Whether the window dynamically scales to the detected screen size.
 
-WINDOW_HEIGHT = 550
-WINDOW_WIDTH = 650
+WINDOW_HEIGHT = 650
+WINDOW_WIDTH = 750
 # Dimensions of “threshold adjustment” and “region selection” windows in pixels. DYNAMIC_WINDOW must be set to False to set these values manually.
 
 WINDOW_X = 10
@@ -128,4 +131,4 @@ FIGURE_FILETYPES = ["pdf"]
 # The filetypes for the output figures. Multiple types can also be selected, e.g., ["png", "pdf", "tif"]. Only use the supported filetypes ("eps", "tif", "ps", "tiff", "rgba", "svg", "png", "jpg", "raw", "pdf", "svgz", "pgf", and "jpeg").
 
 FIGURE_RESOLUTION = 300
-# Resolution (DPI) of the output figures. This is for images only; PDF outputs are unaffected by this value.
\ No newline at end of file
+# Resolution (DPI) of the output figures. This is for images only; PDF outputs are unaffected by this value.
